Crate anno_eval

Crate anno_eval 

Evaluation tooling for anno.

Modules

cdcr
Cross-document coreference / clustering (CDCR).
discourse
Discourse-level analysis: centering theory, abstract anaphora, dialogue acts.
eval
NER and Coreference evaluation framework.
muxer_agg_lib
Aggregate muxer decision/outcome logs. Shared aggregation logic for muxer JSONL logs.
muxer_harness
Shared helpers for the muxer-backed matrix sampler harness. Shared helpers for the muxer-backed eval matrix sampler harness and CLI tooling.
muxer_history
Persistent muxer selection history (shared by CI harness and tooling). Shared muxer history types for the CI matrix sampler harness.
muxer_matrix
Muxer-backed evaluation harness (shared by tests and tooling). CI-friendly randomized matrix test (muxer-backed).

Macros

define_datasets
Macro to define all datasets in a single place.
has_category
Helper macro to check if a list of categories contains a specific category.
impl_category_checks
Helper macro to implement category checking methods.
optional_access_status
Helper macro to handle optional access_status fields in dataset definitions. Returns DatasetAccessibility::Public as the default when not specified.
optional_field
Helper macro to handle optional string fields in dataset definitions.
optional_field_num
Helper macro to handle optional numeric fields in dataset definitions.