pub struct LSHBlocker {
pub num_bands: usize,
pub rows_per_band: usize,
pub ngram_size: usize,
}Expand description
Locality-Sensitive Hashing (LSH) for blocking.
Blocking reduces the O(n²) pairwise comparison problem by grouping likely-coreferent mentions into “blocks” using hash signatures.
Algorithm
- Compute a character n-gram signature for each mention
- Hash the signature using multiple hash functions
- Mentions with identical hash in any band are candidates
This achieves sub-quadratic scaling while maintaining high recall for truly coreferent pairs.
Fields
num_bands: usizeNumber of hash bands
rows_per_band: usizeRows per band
ngram_size: usizeN-gram size for signatures
Implementations
Sourceimpl LSHBlocker
impl LSHBlocker
Sourcepub fn candidate_pairs(&self, mentions: &[MentionRef]) -> Vec<(usize, usize)>
pub fn candidate_pairs(&self, mentions: &[MentionRef]) -> Vec<(usize, usize)>
Compute candidate pairs for a set of mentions.
Returns pairs of indices (i, j) where i < j that are candidates for cross-document coreference.
Sourcepub fn signature_similarity(sig1: &[u64], sig2: &[u64]) -> f64
pub fn signature_similarity(sig1: &[u64], sig2: &[u64]) -> f64
Estimate Jaccard similarity from minhash signatures.