pub struct DiscourseAwareResolver { /* private fields */ }Expand description
Discourse-aware coreference resolver.
This is intended for analysis/eval paths; it does not attempt to be a full abstract-anaphora system. It extracts a small event inventory and uses discourse boundary heuristics to propose clause/sentence antecedent spans for demonstratives and shell-noun phrases.
Implementations
Sourceimpl DiscourseAwareResolver
impl DiscourseAwareResolver
Sourcepub fn new(config: DiscourseCorefConfig, text: &str) -> DiscourseAwareResolver
pub fn new(config: DiscourseCorefConfig, text: &str) -> DiscourseAwareResolver
Create a new discourse-aware resolver.
Sourcepub fn events(&self) -> &[EventMention]
pub fn events(&self) -> &[EventMention]
Get extracted events.
Sourcepub fn resolve_entities(&self, entities: &[Entity]) -> Vec<Entity>
pub fn resolve_entities(&self, entities: &[Entity]) -> Vec<Entity>
Resolve coreference with discourse awareness.
Sourcepub fn resolve(&self, entities: &[Entity]) -> Vec<Entity>
pub fn resolve(&self, entities: &[Entity]) -> Vec<Entity>
Resolve coreference with discourse awareness.
Inherent-method convenience wrapper (so callers don’t need to import the
CoreferenceResolver trait to call resolver.resolve(&entities)).
Sourcepub fn find_discourse_antecedent(
&self,
anaphor: &Entity,
) -> Option<DiscourseReferent>
pub fn find_discourse_antecedent( &self, anaphor: &Entity, ) -> Option<DiscourseReferent>
Find a discourse-level antecedent for an abstract anaphor.