pub struct SimpleCorefResolver { /* private fields */ }Expand description
Simple rule-based coreference resolver.
Applies the nine-sieve pipeline described in the module documentation to assign
CanonicalIds to a sequence of Entity values. Entities that corefer receive the
same id; singletons receive a unique id.
Example
use anno::Entity;
use anno::EntityType;
use anno::backends::coref::simple::{SimpleCorefResolver, CorefConfig};
let resolver = SimpleCorefResolver::new(CorefConfig::default());
let entities = vec![
Entity::new("John Smith", EntityType::Person, 0, 10, 0.9),
Entity::new("he", EntityType::Person, 15, 17, 0.8),
Entity::new("John Smith", EntityType::Person, 30, 40, 0.9),
];
let resolved = resolver.resolve(&entities);
// All three mentions share the same canonical_id.
assert_eq!(resolved[0].canonical_id, resolved[1].canonical_id);
assert_eq!(resolved[0].canonical_id, resolved[2].canonical_id);Implementations
Sourceimpl SimpleCorefResolver
impl SimpleCorefResolver
Sourcepub fn new(config: CorefConfig) -> SimpleCorefResolver
pub fn new(config: CorefConfig) -> SimpleCorefResolver
Create a new resolver with configuration.
Sourcepub fn resolve_entities(&self, entities: &[Entity]) -> Vec<Entity>
pub fn resolve_entities(&self, entities: &[Entity]) -> Vec<Entity>
Resolve coreference for entities, assigning canonical IDs.
Sourcepub fn resolve(&self, entities: &[Entity]) -> Vec<Entity>
pub fn resolve(&self, entities: &[Entity]) -> Vec<Entity>
Resolve coreference for entities.
This is an inherent-method convenience wrapper so callers do not need to import the
CoreferenceResolver trait to call resolver.resolve(&entities).
Sourcepub fn resolve_to_chains(&self, entities: &[Entity]) -> Vec<CorefChain>
pub fn resolve_to_chains(&self, entities: &[Entity]) -> Vec<CorefChain>
Convert resolved entities directly to coreference chains.
Requires the analysis feature.