pub struct DatasetFlags(/* private fields */);Expand description
Dataset capability/category flags.
Using bitflags allows O(1) category checks and easy combination queries.
Implementations
Sourceimpl DatasetFlags
impl DatasetFlags
Sourcepub const COREFERENCE: Self
pub const COREFERENCE: Self
Coreference resolution dataset
Sourcepub const INTRA_DOC_COREF: Self
pub const INTRA_DOC_COREF: Self
Intra-document coreference
Sourcepub const INTER_DOC_COREF: Self
pub const INTER_DOC_COREF: Self
Cross-document / inter-document coreference
Sourcepub const TEMPORAL_NER: Self
pub const TEMPORAL_NER: Self
Temporal NER (dates, durations, temporal expressions)
Sourcepub const BIOMEDICAL: Self
pub const BIOMEDICAL: Self
Biomedical/clinical domain
Sourcepub const SOCIAL_MEDIA: Self
pub const SOCIAL_MEDIA: Self
Social media domain (Twitter, Reddit, etc.)
Sourcepub const SPECIALIZED_DOMAIN: Self
pub const SPECIALIZED_DOMAIN: Self
Specialized domain (not general news)
Sourcepub const RELATION_EXTRACTION: Self
pub const RELATION_EXTRACTION: Self
Relation extraction dataset
Sourcepub const HISTORICAL: Self
pub const HISTORICAL: Self
Historical texts
Sourcepub const BIAS_EVALUATION: Self
pub const BIAS_EVALUATION: Self
Bias evaluation dataset
Sourcepub const DIALOGUE_COREF: Self
pub const DIALOGUE_COREF: Self
Dialogue/conversational coreference
Sourcepub const JOINT_NER_RE: Self
pub const JOINT_NER_RE: Self
Joint NER + Relation Extraction
Sourcepub const DISCONTINUOUS_NER: Self
pub const DISCONTINUOUS_NER: Self
Discontinuous/nested NER
Sourcepub const MULTILINGUAL: Self
pub const MULTILINGUAL: Self
Multilingual dataset
Sourcepub const CONSTRUCTED_LANGUAGE: Self
pub const CONSTRUCTED_LANGUAGE: Self
Constructed/artificial language
Sourcepub const CODE_SWITCHING: Self
pub const CODE_SWITCHING: Self
Code-switching dataset
Sourcepub const AFRICAN_LANGUAGE: Self
pub const AFRICAN_LANGUAGE: Self
African language dataset
Sourcepub const ENTITY_LINKING: Self
pub const ENTITY_LINKING: Self
Entity linking dataset
Sourcepub const EVENT_EXTRACTION: Self
pub const EVENT_EXTRACTION: Self
Event extraction dataset
Sourcepub const SCIENTIFIC: Self
pub const SCIENTIFIC: Self
Scientific domain
Sourcepub const LOW_RESOURCE: Self
pub const LOW_RESOURCE: Self
Low-resource language
Sourceimpl DatasetFlags
impl DatasetFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl DatasetFlags
impl DatasetFlags
Sourcepub const fn iter(&self) -> Iter<DatasetFlags>
pub const fn iter(&self) -> Iter<DatasetFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DatasetFlags>
pub const fn iter_names(&self) -> IterNames<DatasetFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.