pub struct GoldEntity {
pub text: String,
pub entity_type: EntityType,
pub original_label: String,
pub start: usize,
pub end: usize,
}Expand description
Gold standard entity annotation.
This is the canonical entity type for all NER evaluation. Use this instead of creating local entity structs.
Example
use anno_eval::eval::GoldEntity;
use anno::EntityType;
let entity = GoldEntity::new("John Doe", EntityType::Person, 0);
assert_eq!(entity.end, 8);Fields
text: StringThe entity text (surface form)
entity_type: EntityTypeNormalized entity type
original_label: StringOriginal label from dataset (e.g., “B-PER”, “ACTOR”)
start: usizeCharacter offset (start)
end: usizeCharacter offset (end, exclusive)
Implementations
Sourceimpl GoldEntity
impl GoldEntity
Sourcepub fn new(
text: impl Into<String>,
entity_type: EntityType,
start: usize,
) -> Self
pub fn new( text: impl Into<String>, entity_type: EntityType, start: usize, ) -> Self
Create a new gold entity with computed end offset.
Note: Uses character count (not byte count) for Unicode correctness.
Sourcepub fn with_span(
text: impl Into<String>,
entity_type: EntityType,
start: usize,
end: usize,
) -> Self
pub fn with_span( text: impl Into<String>, entity_type: EntityType, start: usize, end: usize, ) -> Self
Create with explicit span (start, end).
Sourcepub fn with_label(
text: impl Into<String>,
entity_type: EntityType,
original_label: impl Into<String>,
start: usize,
) -> Self
pub fn with_label( text: impl Into<String>, entity_type: EntityType, original_label: impl Into<String>, start: usize, ) -> Self
Create with explicit original label.
Note: Uses character count (not byte count) for Unicode correctness.
Sourcepub fn full(
text: impl Into<String>,
entity_type: EntityType,
original_label: impl Into<String>,
start: usize,
end: usize,
) -> Self
pub fn full( text: impl Into<String>, entity_type: EntityType, original_label: impl Into<String>, start: usize, end: usize, ) -> Self
Create with all fields explicit.
Sourcepub fn extract_text(&self, source_text: &str) -> String
pub fn extract_text(&self, source_text: &str) -> String
Safely extract text from source using character offsets.
GoldEntity stores character offsets, not byte offsets. This method correctly extracts text by iterating over characters.
Arguments
source_text- The original text from which this entity was extracted
Returns
The extracted text, or empty string if offsets are invalid
Sourcepub fn span_matches(&self, other: &Self) -> bool
pub fn span_matches(&self, other: &Self) -> bool
Check if spans match exactly.
Sourcepub fn exact_matches(&self, other: &Self) -> bool
pub fn exact_matches(&self, other: &Self) -> bool
Check if this is an exact match (span + type).