pub struct EntityMemory { /* private fields */ }Expand description
Entity memory for incremental coreference.
Stores active clusters and handles eviction based on memory policy.
Implementations
Sourceimpl EntityMemory
impl EntityMemory
Sourcepub fn new(policy: MemoryPolicy) -> Self
pub fn new(policy: MemoryPolicy) -> Self
Create a new entity memory with the given policy.
Sourcepub fn find_best_match(
&self,
mention_text: &str,
mention_type: MentionType,
similarity_threshold: f64,
use_exact_match: bool,
use_substring_match: bool,
) -> Option<u64>
pub fn find_best_match( &self, mention_text: &str, mention_type: MentionType, similarity_threshold: f64, use_exact_match: bool, use_substring_match: bool, ) -> Option<u64>
Find the best matching cluster for a mention.
Sourcepub fn advance_window(&mut self)
pub fn advance_window(&mut self)
Advance to next window.
Sourcepub fn to_chains(&self) -> Vec<CorefChain>
pub fn to_chains(&self) -> Vec<CorefChain>
Get all clusters as coreference chains.
Sourcepub fn cluster_count(&self) -> usize
pub fn cluster_count(&self) -> usize
Get number of active clusters.
Sourcepub fn mention_count(&self) -> usize
pub fn mention_count(&self) -> usize
Get total mention count across all clusters.