pub struct InterDocCorefMetrics {
pub cluster_purity: f64,
pub cluster_completeness: f64,
pub num_pred_identities: usize,
pub num_gold_identities: usize,
pub num_correct: usize,
pub num_total: usize,
}Expand description
Metrics for inter-document coreference resolution quality.
Fields
cluster_purity: f64Cluster purity: average fraction of tracks in each identity that are correct
cluster_completeness: f64Cluster completeness: average fraction of correct tracks that are in the same identity
num_pred_identities: usizeNumber of predicted identities
num_gold_identities: usizeNumber of gold identities
num_correct: usizeNumber of tracks correctly clustered
num_total: usizeTotal number of tracks
Implementations