pub struct MultiRunEvaluator { /* private fields */ }Expand description
Multi-run evaluator for NER models.
Runs evaluation multiple times and aggregates results with statistics.
Implementations
Sourceimpl MultiRunEvaluator
impl MultiRunEvaluator
Sourcepub fn new(config: MultiRunConfig) -> Self
pub fn new(config: MultiRunConfig) -> Self
Create a new evaluator with the given config.
Sourcepub fn default_config() -> Self
pub fn default_config() -> Self
Create with default config.
Sourcepub fn evaluate(
&self,
model: &dyn Model,
test_cases: &[(String, Vec<GoldEntity>)],
) -> Result<MultiRunResults>
pub fn evaluate( &self, model: &dyn Model, test_cases: &[(String, Vec<GoldEntity>)], ) -> Result<MultiRunResults>
Evaluate a model on test cases with multiple runs.
Sourcepub fn quick_eval(
model: &dyn Model,
test_cases: &[(String, Vec<GoldEntity>)],
) -> Result<MultiRunResults>
pub fn quick_eval( model: &dyn Model, test_cases: &[(String, Vec<GoldEntity>)], ) -> Result<MultiRunResults>
Quick evaluation with 3 runs (suitable for development).
Sourcepub fn thorough_eval(
model: &dyn Model,
test_cases: &[(String, Vec<GoldEntity>)],
) -> Result<MultiRunResults>
pub fn thorough_eval( model: &dyn Model, test_cases: &[(String, Vec<GoldEntity>)], ) -> Result<MultiRunResults>
Thorough evaluation with 10 runs (suitable for publication).