pub struct BoundingBox {
pub x1: f32,
pub y1: f32,
pub x2: f32,
pub y2: f32,
}Expand description
A bounding box in normalized coordinates (0.0-1.0).
Using normalized coordinates allows consistent evaluation regardless of image resolution.
Fields
x1: f32Left coordinate (0.0-1.0)
y1: f32Top coordinate (0.0-1.0)
x2: f32Right coordinate (0.0-1.0)
y2: f32Bottom coordinate (0.0-1.0)
Implementations
Sourceimpl BoundingBox
impl BoundingBox
Sourcepub fn iou(&self, other: &BoundingBox) -> f32
pub fn iou(&self, other: &BoundingBox) -> f32
Calculate Intersection-over-Union (IoU) with another box.
IoU = intersection_area / union_area Range: 0.0 (no overlap) to 1.0 (identical boxes)
Sourcepub fn overlaps(&self, other: &BoundingBox, threshold: f32) -> bool
pub fn overlaps(&self, other: &BoundingBox, threshold: f32) -> bool
Check if this box substantially overlaps with another (IoU >= threshold).