macro_rules! optional_field {
() => { ... };
($value:literal) => { ... };
}Expand description
Helper macro to handle optional string fields in dataset definitions.
macro_rules! optional_field {
() => { ... };
($value:literal) => { ... };
}Helper macro to handle optional string fields in dataset definitions.