anno-eval 0.10.0

Evaluation harnesses, datasets, and muxer-backed sampling for anno
docs.rs failed to build anno-eval-0.10.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: anno-eval-0.6.0

Evaluation tooling for anno.